@@ -527,20 +527,18 @@ namespace gnote {
     while(m1 != m2) {
       const boost::sub_match<std::string::const_iterator> & match = (*m1)[1];
 
-      /*
-        Logger.Log ("Highlighting url: '{0}' at offset {1}",
-        group,
-        group.Index);
-      */
-
       Gtk::TextIter start_cpy = start;
-      start_cpy.forward_chars (match.first - s.begin());
+      // must construct the Glib::ustring from a std:;string.
+      // otherwise it expect the num of chars (UTF-8) instead of bytes.
+      Glib::ustring segment(std::string(s.c_str(), match.first - s.begin()));
+      start_cpy.forward_chars (segment.size());
 
       end = start_cpy;
-      end.forward_chars (match.length());
+      // here match.str() is the std::string we need. All good.
+      Glib::ustring segment2(match.str());
+      end.forward_chars (segment2.length());
 
-      std::string debug = start_cpy.get_slice(end);
-      DBG_OUT("url is %s", debug.c_str());
+      DBG_OUT("url is %s", segment2.c_str());
       get_buffer()->apply_tag (m_url_tag, start_cpy, end);
       ++m1;
     }
@@ -780,7 +778,7 @@ namespace gnote {
 
       Gtk::TextIter start_iter = range.start();
       Gtk::TextIter end_iter = range.end();
-      get_buffer()->erase (start_iter, end_iter);
+      end_iter = get_buffer()->erase (start_iter, end_iter);
       start_iter = range.start();
       get_buffer()->insert_with_tag(start_iter, renamed->get_title(), m_link_tag);
     }
@@ -847,7 +845,7 @@ namespace gnote {
     int idx = 0;
 
     while (true) {
-      idx = sharp::string_index_of(buffer_text, sharp::string_substring(find_title_lower, idx));
+      idx = sharp::string_index_of(buffer_text, find_title_lower, idx);
       if (idx < 0)
         break;
 
@@ -1043,19 +1041,20 @@ namespace gnote {
     boost::sregex_iterator m1(s.begin(), s.end(), m_regex);
     boost::sregex_iterator m2;
     while(m1 != m2) {
-      /// TODO iterator throught the WHOLE match
       const boost::sub_match<std::string::const_iterator> & match = (*m1)[1];
 
       if (match.matched && !is_patronymic_name (match.str())) {
 
-        DBG_OUT("Highlighting wikiword: '%s' at offset %d",
-                match.str().c_str(), (match.first - s.begin()));
       
         Gtk::TextIter start_cpy = start;
-        start_cpy.forward_chars (match.first - s.begin());
+        Glib::ustring segment(std::string(s.c_str(), match.first - s.begin()));
+        start_cpy.forward_chars (segment.length());
+        DBG_OUT("Highlighting wikiword: '%s' at offset %d",
+                match.str().c_str(), segment.length());
 
         end = start_cpy;
-        end.forward_chars (match.length());
+        segment = match.str();
+        end.forward_chars (segment.length());
 
         if (!manager().find (match.str())) {
           get_buffer()->apply_tag (m_broken_link_tag, start_cpy, end);
